# GET PRIME NUMBER

Python module that returns a generator of prime numbers.

## Instructions

1. Install the module
```
$ pip install get-prime-number
```

2. Import the function
```
from get-prime-number import get_prime_number
```

3. Create the generator
```
prime_numbers = get_prime_number()
```

4. Iterate through prime numbers
```
print(next(prime_numbers))
```

Have fun! If you have any trouble, please, contact me.
